@@ -8,14 +8,13 @@
  *
  * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CORE_DB_ALBUM_INFO_H
-#define DIGIKAM_CORE_DB_ALBUM_INFO_H
+#pragma once
 
 // Qt includes
 
@@ -33,7 +32,7 @@ namespace Digikam
 typedef QPair<int, int> YearMonth;
 
 /**
- * \class AlbumRootInfo
+ * @class AlbumRootInfo
  */
 class AlbumRootInfo
 {
@@ -55,7 +54,7 @@ public:
 // --------------------------------------------------------------------------
 
 /**
- * \class AlbumInfo
+ * @class AlbumInfo
  * A container class for transporting album information
  * from the database to AlbumManager
  */
@@ -98,7 +97,7 @@ public:
 // --------------------------------------------------------------------------
 
 /**
- * \class TagInfo
+ * @class TagInfo
  * A container class for transporting tag information
  * from the database to AlbumManager
  */
@@ -134,7 +133,7 @@ public:
 // --------------------------------------------------------------------------
 
 /**
- * \class SearchInfo
+ * @class SearchInfo
  * A container class for transporting search information
  * from the database to AlbumManager
  */
@@ -378,5 +377,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_CORE_DB_ALBUM_INFO_H
