@@ -6,17 +6,16 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONFIG_H
-#define DIGIKAM_CONFIG_H
+#pragma once
 
 /* Define to 1 if you have KDEPIM shared library installed */
-/* #undef HAVE_AKONADICONTACT */
+#define HAVE_AKONADICONTACT 1
 
 /* Define to 1 if an external lensfun shared library have been found */
 #define HAVE_LENSFUN 1
@@ -51,6 +50,9 @@
 /* Define to 1 if Jasper shared library is installed */
 #define HAVE_JASPER 1
 
+/* Define to 1 if libjxl shared library is installed */
+#define HAVE_JXL 1
+
 /* Define to 1 if libgphoto2 2.5 shared library is installed */
 #define HAVE_GPHOTO25 1
 
@@ -102,18 +104,10 @@
 /* Define to 1 if system use QtMultimedia */
 #define HAVE_QTMULTIMEDIA 1
 
-/* Define to 1 if system use QtWebEngine */
-#define HAVE_QWEBENGINE 1
-
 /* Define to 1 if system use QtXmlPatterns */
 /* #undef HAVE_QTXMLPATTERNS */
 
 /* Define to 1 if ImageMagick codecs are supported */
 #define HAVE_IMAGE_MAGICK 1
 
-/* Defines to 1 if the Dr. Mingw crash handler should be used */
-/* #undef HAVE_DRMINGW */
-
 #define LIBEXEC_INSTALL_DIR "/usr/libexec"
-
-#endif // DIGIKAM_CONFIG_H
